<?php
/**
*
* @package Moods
* @copyright (c) 2016 Theriddler - (http://www.peppersrus-forum.nl)
* @copyright (c) 2015 Rmcgirr83
* @Code lent from nationalflags extension by Rmcgirr83
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace theriddler\moods\controller;

use Symfony\Component\HttpKernel\Exception\NotFoundHttpException;
use Symfony\Component\HttpFoundation\Response;
use phpbb\exception\http_exception;

/**
* Main controller
*/
class main_controller
{
	/** @var \phpbb\auth\auth */
	protected $auth;

	/** @var \phpbb\cache\service */
	protected $cache;

	/** @var \phpbb\config\config */
	protected $config;

	/** @var \phpbb\db\driver\driver */
	protected $db;
	
	/** @var \phpbb\pagination */
	protected $pagination;

	/** @var \phpbb\controller\helper */
	protected $helper;

	/* @var \phpbb\request\request */
	protected $request;

	/** @var \phpbb\extension\manager "Extension Manager" */
	protected $ext_manager;

	/** @var \phpbb\path_helper */
	protected $path_helper;

	/** @var \phpbb\template\template */
	protected $template;

	/** @var \phpbb\user */
	protected $user;

	/** @var string phpBB root path */
	protected $root_path;

	/** @var string phpEx */
	protected $php_ext;

	/**
	* The database table the moods are stored in
	*
	* @var string
	*/
	protected $moods_table;

	/* @var \theriddler\moods\core\moods */
	protected $functions;

	/**
	* Constructor
	*
	* @param \phpbb\auth\auth					$auth			Auth object
	* @param \phpbb\cache\service				$cache			Cache object
	* @param \phpbb\config\config               $config         Config object
	* @param \phpbb\db\driver\driver			$db				Database object
	* @param \phpbb\pagination					$pagination		Pagination object
	* @param \phpbb\controller\helper           $helper         Controller helper object
	* @param \phpbb\request\request				$request		Request object
	* @param \phpbb\extension\manager			$ext_manager	Extension manager object
	* @param \phpbb\path_helper					$path_helper	Path helper object
	* @param \phpbb\template\template           $template       Template object
	* @param \phpbb\user                        $user           User object
	* @param string                             $root_path      phpBB root path
	* @param string                             $php_ext        phpEx
	* @param string								$moods_table	Name of the table used to store mood data
	* @param \theriddler\moods\core\moods		$functions		functions to be used by class
	* @access public
	*/
	public function __construct(
			\phpbb\auth\auth $auth,
			\phpbb\cache\service $cache,
			\phpbb\config\config $config,
			\phpbb\db\driver\driver_interface $db,
			\phpbb\pagination $pagination,
			\phpbb\controller\helper $helper,
			\phpbb\request\request $request,
			\phpbb\extension\manager $ext_manager,
			\phpbb\path_helper $path_helper,
			\phpbb\template\template $template,
			\phpbb\user $user,
			$root_path,
			$php_ext,
			$moods_table,
			\theriddler\moods\core\moods $functions)
	{
		$this->auth = $auth;
		$this->cache = $cache;
		$this->config = $config;
		$this->db = $db;
		$this->pagination = $pagination;
		$this->helper = $helper;
		$this->request = $request;
		$this->ext_manager	 = $ext_manager;
		$this->path_helper	 = $path_helper;
		$this->template = $template;
		$this->user = $user;
		$this->root_path = $root_path;
		$this->php_ext = $php_ext;
		$this->moods_table = $moods_table;
		$this->functions = $functions;

		$this->ext_path = $this->ext_manager->get_extension_path('theriddler/moods', true);
	}

	/**
	 * Display mood on change in ucp
	 * Ajax function
	 * @param $mood_id
	 *
	 * @return \Symfony\Component\HttpFoundation\Response
	 */
	public function getMood($mood_id)
	{
		if (empty($mood_id))
		{
			return new Response($this->user->lang['NO_SUCH_MOOD']);
		}

		$moods = $this->cache->get('_user_moods');

		$mood_img = $this->ext_path . 'moods/' . strtolower($moods[$mood_id]['mood_image']);
		$mood_img = str_replace('./', generate_board_url() . '/', $mood_img); //fix paths

		$mood_name = $moods[$mood_id]['mood_name'];

		$return = '<img class="mood_image" src="' . $mood_img . '" alt="' . $mood_name . '" title="' . $mood_name . '" />';

		return new Response($return);
	}
}
