<?php
/**
*
* @package Moods
* @copyright (c) 2016 Theriddler - (http://www.peppersrus-forum.nl)
* @copyright (c) 2015 Rmcgirr83
* @Code lent from nationalflags extension by Rmcgirr83
* @license http://opensource.org/licenses/gpl-2.0.php GNU General Public License v2
*
*/

namespace theriddler\moods\core;

class moods
{

	/** @var \phpbb\config\config */
	protected $config;

	/** @var \phpbb\controller\helper */
	protected $helper;

	/** @var \phpbb\cache\service */
	protected $cache;

	/** @var \phpbb\db\driver\driver */
	protected $db;

	/** @var \phpbb\template\template */
	protected $template;

	/** @var \phpbb\user */
	protected $user;

	/**
	 * The database table the rules are stored in
	 *
	 * @var string
	 */
	protected $moods_table;

	/** @var \phpbb\extension\manager "Extension Manager" */
	protected $ext_manager;

	/** @var \phpbb\path_helper */
	protected $path_helper;

	/**
	 * Constructor
	 *
	 * @param \phpbb\config\config			$config				Config object
	 * @param \phpbb\controller\helper		$helper				Controller helper object
	 * @param \phpbb\cache\service			$cache				Cache object
	 * @param \phpbb\db\driver\driver		$db					Database object
	 * @param \phpbb\template\template		$template			Template object
	 * @param \phpbb\user					$user				User object
	 * @param string						$moods_table		Name of the table used to store mood data
	 * @param \phpbb\extension\manager		$ext_manager		Extension manager object
	 * @param \phpbb\path_helper			$path_helper		Path helper object
	 */
	public function __construct(
			\phpbb\config\config $config,
			\phpbb\controller\helper $helper,
			\phpbb\cache\service $cache,
			\phpbb\db\driver\driver_interface $db,
			\phpbb\template\template $template,
			\phpbb\user $user,
			$moods_table,
			\phpbb\extension\manager $ext_manager,
			\phpbb\path_helper $path_helper)
	{
		$this->config = $config;
		$this->helper = $helper;
		$this->cache = $cache;
		$this->db = $db;
		$this->template = $template;
		$this->user = $user;
		$this->moods_table = $moods_table;
		$this->ext_manager	 = $ext_manager;
		$this->path_helper	 = $path_helper;

		$this->ext_path = $this->ext_manager->get_extension_path('theriddler/moods', true);
		$this->ext_path_web = $this->path_helper->update_web_root_path($this->ext_path);
	}

	/**
	 * Get user mood
	 *
	 * @return string mood
	 */

	public function get_user_mood($mood_id = false)
	{
		$moods = $this->cache->get('_user_moods');

		if ($mood_id)
		{
			$mood = '<img class="mood_image" src="' . $this->ext_path_web . 'moods/' . strtolower($moods[$mood_id]['mood_image']) . '" alt="' . $moods[$mood_id]['mood_name'] . '" title="' . $moods[$mood_id]['mood_name'] . '" />';

			return $mood;
		}
		return false;
	}
	/**
	 * cache_moods
	 *
	 * Build the cache of the moods
	 *
	 * @return null
	 */

	public function cache_moods()
	{
		if (($this->cache->get('_user_moods')) === false)
		{
			$sql = 'SELECT mood_id, mood_name, mood_image
				FROM ' . $this->moods_table . '
			ORDER BY mood_id';
			$result = $this->db->sql_query($sql);

			$user_moods = array();
			while ($row = $this->db->sql_fetchrow($result))
			{
				$user_moods[$row['mood_id']] = array(
					'mood_id'		=> $row['mood_id'],
					'mood_name'		=> $row['mood_name'],
					'mood_image'	=> $row['mood_image'],
				);
			}
			$this->db->sql_freeresult($result);

			// cache this data for ever, can only change in ACP
			$this->cache->put('_user_moods', $user_moods);
		}
	}

	/**
	 * Get list_moods
	 *
	 * @param int $mood_id
	 * @return string mood_options
	 */

	public function list_moods($mood_id)
	{
		$sql = 'SELECT mood_id, mood_name, mood_image
			FROM ' . $this->moods_table . '
		ORDER BY mood_name';
		$result = $this->db->sql_query($sql);

		$mood_options = '<option value="0">' . $this->user->lang['MOOD_EXPLAIN'] . '</option>';
		while ($row = $this->db->sql_fetchrow($result))
		{
			$selected = ($row['mood_id'] == $mood_id) ? ' selected="selected"' : '';
			$mood_options .= '<option value="' . $row['mood_id'] . '" ' . $selected . '>' . $row['mood_name'] . '</option>';
		}
		$this->db->sql_freeresult($result);

		return $mood_options;
	}
}
